# sloom

UNDER DEVELOPMENT v 0.1.1

I don't know what this will be yet but I am planning on making a web scraper package I can continue to work on

## Setup

to get use 
```
pip install -i https://test.pypi.org/simple/ sloom
```

to update use
```
 pip install -i https://test.pypi.org/simple/ sloom --upgrade
 ```
